![Logo](https://github.com/danedane-haider/HybrA-Filterbanks/assets/55834940/5a7f4ec5-86a3-47b8-bdd0-fd92943f8b1b)

> [!WARNING]
> Still under development.

Provide a *pth file with a dictionary containing the following keys: auditory_filters_real, auditory_filters_imag, auditory_filters_stride, n_filters, kernel_size

see auditory_filters_speech.pth as example
